pub struct CameraSwitched {
pub previous: Option<Entity>,
pub current: Entity,
}Expand description
Switch request and switch event messages emitted by CameraSwitchPlugin.
Fields
previous: Option<Entity>current: EntityTrait Implementations
Sourceimpl Clone for CameraSwitched
impl Clone for CameraSwitched
Sourcefn clone(&self) -> CameraSwitched
fn clone(&self) -> CameraSwitched
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CameraSwitched
Sourceimpl Debug for CameraSwitched
impl Debug for CameraSwitched
impl Eq for CameraSwitched
impl Message for CameraSwitched
Sourceimpl PartialEq for CameraSwitched
impl PartialEq for CameraSwitched
Sourcefn eq(&self, other: &CameraSwitched) -> bool
fn eq(&self, other: &CameraSwitched) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CameraSwitched